[Bf-blender-cvs] [fbcb9207489] blender2.8: Rename circle_partial -> disk_partial

Campbell Barton noreply at git.blender.org
Mon Apr 3 14:11:33 CEST 2017


Commit: fbcb92074893480aa7c2ec14357f1f1a62f63f6a
Author: Campbell Barton
Date:   Mon Apr 3 22:08:40 2017 +1000
Branches: blender2.8
https://developer.blender.org/rBfbcb92074893480aa7c2ec14357f1f1a62f63f6a

Rename circle_partial -> disk_partial

We may have a 'disk' function (not the partial version).

===================================================================

M	source/blender/editors/include/BIF_glutil.h
M	source/blender/editors/screen/glutil.c

===================================================================

diff --git a/source/blender/editors/include/BIF_glutil.h b/source/blender/editors/include/BIF_glutil.h
index 53bfef7cad6..ebc6cd86479 100644
--- a/source/blender/editors/include/BIF_glutil.h
+++ b/source/blender/editors/include/BIF_glutil.h
@@ -89,7 +89,7 @@ void imm_draw_filled_circle(unsigned pos, float x, float y, float radius, int ns
  * \param start: Specifies the starting angle, in degrees, of the disk portion.
  * \param sweep: Specifies the sweep angle, in degrees, of the disk portion.
  */
-void imm_draw_filled_circle_partial(
+void imm_draw_filled_disk_partial(
         unsigned pos, float x, float y,
         float radius_inner, float radius_outer, int nsegments, float start, float sweep);
 
diff --git a/source/blender/editors/screen/glutil.c b/source/blender/editors/screen/glutil.c
index a613537100b..13e3fa2f50b 100644
--- a/source/blender/editors/screen/glutil.c
+++ b/source/blender/editors/screen/glutil.c
@@ -104,9 +104,9 @@ void imm_draw_filled_circle(unsigned pos, float x, float y, float rad, int nsegm
 }
 
 /**
  * \note We could have `imm_draw_lined_circle_partial` but currently there is no need.
  */
-static void imm_draw_circle_partial(
+static void imm_draw_disk_partial(
         PrimitiveType prim_type, unsigned pos, float x, float y,
         float rad_inner, float rad_outer, int nsegments, float start, float sweep)
 {
@@ -128,11 +128,11 @@ static void imm_draw_circle_partial(
 /**
  * Replacement for gluPartialDisk, (without 'loops' argument).
  */
-void imm_draw_filled_circle_partial(
+void imm_draw_filled_disk_partial(
         unsigned pos, float x, float y,
         float rad_inner, float rad_outer, int nsegments, float start, float sweep)
 {
-	imm_draw_circle_partial(PRIM_TRIANGLE_STRIP, pos, x, y, rad_inner, rad_outer, nsegments, start, sweep);
+	imm_draw_disk_partial(PRIM_TRIANGLE_STRIP, pos, x, y, rad_inner, rad_outer, nsegments, start, sweep);
 }
 
 void imm_draw_lined_circle_3D(unsigned pos, float x, float y, float rad, int nsegments)
@@ -104,9 +104,9 @@ void imm_draw_filled_circle(unsigned pos, float x, float y, float rad, int nsegm
 
 /**
- * \note We could have `imm_draw_lined_circle_partial` but currently there is no need.
+ * \note We could have `imm_draw_lined_disk_partial` but currently there is no need.
  */




More information about the Bf-blender-cvs mailing list